
-------------------------------------------------------------------------------
-- Optimization
-------------------------------------------------------------------------------

-- GLOBALS: _G, CreateFrame, GameTooltip, MinimapMailFrameUpdate, SixUI_MailButton, SixUI_Minimap, TimeManagerClockButton, TimeManagerClockTicker

local GetMinimapZoneText = GetMinimapZoneText
local GetZonePVPInfo = GetZonePVPInfo
local HasNewMail = HasNewMail
local unpack = unpack
local ZoneText = SixUI_MinimapButtons.ZoneText

-------------------------------------------------------------------------------
-- Namespace
-------------------------------------------------------------------------------

local A, B, C, D = unpack(select(2, ...)) -- AddOn, Border, Constants, Database
local M = A:NewModule("Minimap Buttons")

-------------------------------------------------------------------------------
-- Module
-------------------------------------------------------------------------------

function M:OnEnable()
	self:CreateZoneText()
	self:CreateClockButton()
	self:CreateMailButton()
end

function M:CreateButton(buttonName, glyph)
	if _G[buttonName] then
		return
	end

	local button = CreateFrame("Button", buttonName, SixUI_Minimap)

	button.glyph = button:CreateFontString(nil, "OVERLAY", "GameFontNormal")
	button.glyph:SetFontObject(C.GLYPH_LARGE)
	button.glyph:SetPoint("CENTER")
	button.glyph:SetText(glyph)

	button:SetWidth(button.glyph:GetStringWidth())
	button:SetHeight(button.glyph:GetStringHeight())

	return button
end

-------------------------------------------------------------------------------
-- Clock Button
-------------------------------------------------------------------------------

function M:CreateClockButton()
	TimeManagerClockTicker:SetPoint("CENTER")
	TimeManagerClockTicker:SetFontObject(C.TEXT_REGULAR)
	TimeManagerClockButton:SetParent(SixUI_Minimap)
	TimeManagerClockButton:ClearAllPoints()
	TimeManagerClockButton:SetPoint("CENTER", SixUI_Minimap, "BOTTOM", 0, C.MINIMAP_BUTTON_INSET)
	TimeManagerClockButton:DisableDrawLayer("BORDER")
	TimeManagerClockButton:Show()
end

-------------------------------------------------------------------------------
-- Mail Button
-------------------------------------------------------------------------------

local function MailButton_OnEnter(self)
	GameTooltip:SetOwner(self, "ANCHOR_BOTTOMLEFT")
	MinimapMailFrameUpdate()
end

function M:CreateMailButton()
	local MailButton = M:CreateButton("SixUI_MailButton", C.Enum.Glyph.Envelope)

	MailButton:SetPoint("CENTER", SixUI_Minimap, "BOTTOMRIGHT", -C.MINIMAP_BUTTON_INSET, C.MINIMAP_BUTTON_INSET)
	MailButton:SetScript("OnEnter", MailButton_OnEnter)

	self:RegisterEvent("UPDATE_PENDING_MAIL", "UpdateMailButton")
	self:UpdateMailButton()
end

function M:UpdateMailButton()
	if HasNewMail() then
		SixUI_MailButton:Show()
	else
		SixUI_MailButton:Hide()
	end
end

-------------------------------------------------------------------------------
-- Zone Text
-------------------------------------------------------------------------------

function M:CreateZoneText()
	ZoneText:SetFontObject(C.TEXT_REGULAR)
	self:RegisterEvent("ZONE_CHANGED", "UpdateZoneText")
	self:RegisterEvent("ZONE_CHANGED_INDOORS", "UpdateZoneText")
	self:RegisterEvent("ZONE_CHANGED_NEW_AREA", "UpdateZoneText")
	self:UpdateZoneText()
end

function M:UpdateZoneText()
	ZoneText:SetText(GetMinimapZoneText())
	ZoneText:SetTextColor(unpack(C.PVP_TYPE_TO_COLOR[GetZonePVPInfo()]))
end
